==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/modules/order_total/ot_sofort.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	ot_sofort.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_ORDER_TOTAL_SOFORT_ALLOWED_DESC' => 'Geben Sie <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_ORDER_TOTAL_SOFORT_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_ORDER_TOTAL_SOFORT_BREAK_DESC' => 'Sollten Mehrfachberechnungen möglich sein? Wenn nein, wird nach dem ersten passenden Rabatt abgebrochen.',
	'MODULE_ORDER_TOTAL_SOFORT_BREAK_TITLE' => 'Mehrfachberechnung',
	'MODULE_ORDER_TOTAL_SOFORT_CALC_TAX_DESC' => 'erneutes berechnen der Ust Summe',
	'MODULE_ORDER_TOTAL_SOFORT_CALC_TAX_TITLE' => 'Ust Berechnung',
	'MODULE_ORDER_TOTAL_SOFORT_DESCRIPTION' => 'Rabatt für Zahlungsarten von sofort.com',
	'MODULE_ORDER_TOTAL_SOFORT_DISCOUNT' => 'Rabatt',
	'MODULE_ORDER_TOTAL_SOFORT_FEE' => 'Zuschlag',
	'MODULE_ORDER_TOTAL_SOFORT_INC_SHIPPING_DESC' => 'Versandkosten werden mit rabattiert',
	'MODULE_ORDER_TOTAL_SOFORT_INC_SHIPPING_TITLE' => 'Inklusive Versandkosten',
	'MODULE_ORDER_TOTAL_SOFORT_INC_TAX_DESC' => 'Ust wird mit rabattiert',
	'MODULE_ORDER_TOTAL_SOFORT_INC_TAX_TITLE' => 'Inklusive Ust',
	'MODULE_ORDER_TOTAL_SOFORT_PERCENTAGE_LS_DESC' => 'Rabattierung (Mindestwert:Prozent&Festbetrag)',
	'MODULE_ORDER_TOTAL_SOFORT_PERCENTAGE_LS_TITLE' => 'Rabattstaffel für Lastschrift by SOFORT',
	'MODULE_ORDER_TOTAL_SOFORT_PERCENTAGE_SL_DESC' => 'Rabattierung (Mindestwert:Prozent&Festbetrag)',
	'MODULE_ORDER_TOTAL_SOFORT_PERCENTAGE_SL_TITLE' => 'Rabattstaffel für SOFORT Lastschrift',
	'MODULE_ORDER_TOTAL_SOFORT_PERCENTAGE_SR_DESC' => 'Rabattierung (Mindestwert:Prozent&Festbetrag)',
	'MODULE_ORDER_TOTAL_SOFORT_PERCENTAGE_SR_TITLE' => 'Rabattstaffel für Rechnung by SOFORT',
	'MODULE_ORDER_TOTAL_SOFORT_PERCENTAGE_SU_DESC' => 'Rabattierung (Mindestwert:Prozent&Festbetrag)',
	'MODULE_ORDER_TOTAL_SOFORT_PERCENTAGE_SU_TITLE' => 'Rabattstaffel für SOFORT Überweisung',
	'MODULE_ORDER_TOTAL_SOFORT_PERCENTAGE_SV_DESC' => 'Rabattierung (Mindestwert:Prozent&Festbetrag)',
	'MODULE_ORDER_TOTAL_SOFORT_PERCENTAGE_SV_TITLE' => 'Rabattstaffel für Vorkasse by SOFORT',
	'MODULE_ORDER_TOTAL_SOFORT_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt.',
	'MODULE_ORDER_TOTAL_SOFORT_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_ORDER_TOTAL_SOFORT_STATUS_DESC' => 'Wollen Sie den Zahlungsartenrabatt einschalten?',
	'MODULE_ORDER_TOTAL_SOFORT_STATUS_TITLE' => 'Rabatt anzeigen',
	'MODULE_ORDER_TOTAL_SOFORT_TAX_CLASS_DESC' => 'Die Steuerklasse spielt keine Rolle und dient nur der Vermeidung einer Fehlermeldung.',
	'MODULE_ORDER_TOTAL_SOFORT_TAX_CLASS_TITLE' => 'Steuerklasse',
	'MODULE_ORDER_TOTAL_SOFORT_TITLE' => 'sofort.de Rabattmodul'
);

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/order_total/ot_sofort.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	ot_sofort.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_ORDER_TOTAL_SOFORT_ALLOWED_DESC' => 'Gib <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_ORDER_TOTAL_SOFORT_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_ORDER_TOTAL_SOFORT_BREAK_DESC' => 'Sollten Mehrfachberechnungen möglich sein? Wenn nein, wird nach dem ersten passenden Rabatt abgebrochen.',
	'MODULE_ORDER_TOTAL_SOFORT_BREAK_TITLE' => 'Mehrfachberechnung',
	'MODULE_ORDER_TOTAL_SOFORT_CALC_TAX_DESC' => 'erneutes berechnen der Ust Summe',
	'MODULE_ORDER_TOTAL_SOFORT_CALC_TAX_TITLE' => 'Ust Berechnung',
	'MODULE_ORDER_TOTAL_SOFORT_DESCRIPTION' => 'Rabatt für Zahlungsarten von sofort.com',
	'MODULE_ORDER_TOTAL_SOFORT_DISCOUNT' => 'Rabatt',
	'MODULE_ORDER_TOTAL_SOFORT_FEE' => 'Zuschlag',
	'MODULE_ORDER_TOTAL_SOFORT_INC_SHIPPING_DESC' => 'Versandkosten werden mit rabattiert',
	'MODULE_ORDER_TOTAL_SOFORT_INC_SHIPPING_TITLE' => 'Inklusive Versandkosten',
	'MODULE_ORDER_TOTAL_SOFORT_INC_TAX_DESC' => 'Ust wird mit rabattiert',
	'MODULE_ORDER_TOTAL_SOFORT_INC_TAX_TITLE' => 'Inklusive Ust',
	'MODULE_ORDER_TOTAL_SOFORT_PERCENTAGE_LS_DESC' => 'Rabattierung (Mindestwert:Prozent&Festbetrag)',
	'MODULE_ORDER_TOTAL_SOFORT_PERCENTAGE_LS_TITLE' => 'Rabattstaffel für Lastschrift by SOFORT',
	'MODULE_ORDER_TOTAL_SOFORT_PERCENTAGE_SL_DESC' => 'Rabattierung (Mindestwert:Prozent&Festbetrag)',
	'MODULE_ORDER_TOTAL_SOFORT_PERCENTAGE_SL_TITLE' => 'Rabattstaffel für SOFORT Lastschrift',
	'MODULE_ORDER_TOTAL_SOFORT_PERCENTAGE_SR_DESC' => 'Rabattierung (Mindestwert:Prozent&Festbetrag)',
	'MODULE_ORDER_TOTAL_SOFORT_PERCENTAGE_SR_TITLE' => 'Rabattstaffel für Rechnung by SOFORT',
	'MODULE_ORDER_TOTAL_SOFORT_PERCENTAGE_SU_DESC' => 'Rabattierung (Mindestwert:Prozent&Festbetrag)',
	'MODULE_ORDER_TOTAL_SOFORT_PERCENTAGE_SU_TITLE' => 'Rabattstaffel für SOFORT Überweisung',
	'MODULE_ORDER_TOTAL_SOFORT_PERCENTAGE_SV_DESC' => 'Rabattierung (Mindestwert:Prozent&Festbetrag)',
	'MODULE_ORDER_TOTAL_SOFORT_PERCENTAGE_SV_TITLE' => 'Rabattstaffel für Vorkasse by SOFORT',
	'MODULE_ORDER_TOTAL_SOFORT_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt.',
	'MODULE_ORDER_TOTAL_SOFORT_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_ORDER_TOTAL_SOFORT_STATUS_DESC' => 'Willst du den Zahlungsartenrabatt einschalten?',
	'MODULE_ORDER_TOTAL_SOFORT_STATUS_TITLE' => 'Rabatt anzeigen',
	'MODULE_ORDER_TOTAL_SOFORT_TAX_CLASS_DESC' => 'Die Steuerklasse spielt keine Rolle und dient nur der Vermeidung einer Fehlermeldung.',
	'MODULE_ORDER_TOTAL_SOFORT_TAX_CLASS_TITLE' => 'Steuerklasse',
	'MODULE_ORDER_TOTAL_SOFORT_TITLE' => 'sofort.de Rabattmodul'
);
